@@ -33,16 +33,12 @@ docx_str.flextable <- function(x, align = "center", split = FALSE, doc = NULL, .
   out = paste0(out,  "</w:tblGrid>" )
 
   if( nrow_part(x, "header") > 0 ){
-    x$header <- correct_h_border(x$header)
-    x$header <- correct_v_border(x$header)
     xml_content <- format(x$header, header = TRUE, split = split, type = "wml")
     imgs <- append( imgs, attr(xml_content, "imgs")$image_src )
     hlinks <- append( hlinks, attr(xml_content, "htxt")$href )
     out = paste0(out, xml_content )
   }
   if( nrow_part(x, "body") > 0 ){
-    x$body <- correct_h_border(x$body)
-    x$body <- correct_v_border(x$body)
     xml_content <- format(x$body, header = FALSE, split = split, type = "wml")
     imgs <- append( imgs, attr(xml_content, "imgs")$image_src )
     hlinks <- append( hlinks, attr(xml_content, "htxt")$href )
@@ -50,8 +46,6 @@ docx_str.flextable <- function(x, align = "center", split = FALSE, doc = NULL, .
     out = paste0(out, xml_content )
   }
   if( nrow_part(x, "footer") > 0 ){
-    x$footer <- correct_h_border(x$footer)
-    x$footer <- correct_v_border(x$footer)
     xml_content <- format(x$footer, header = FALSE, split = split, type = "wml")
     imgs <- append( imgs, attr(xml_content, "imgs")$image_src )
     hlinks <- append( hlinks, attr(xml_content, "htxt")$href )
