@@ -72,14 +72,15 @@ set_formatter_type <- function(x, fmt_double = "%.03f", fmt_integer = "%.0f",
 }
 
 #' @export
-#' @title format character columns
-#' @description Format character columns in a flextable.
+#' @title format character cells
+#' @description Format character cells in a flextable.
 #' @param x a flextable object
 #' @param col_keys names of the colkeys
 #' @param na_str string to be used for NA values
 #' @param prefix,suffix string to be used as prefix or suffix
-#' @param ... additional arguments, unused
-#' @family columns formatters
+#' @param ... additional arguments, i can be used to specify a
+#' row selector.
+#' @family cells formatters
 #' @examples
 #' dat <- iris
 #' ft <- flextable(dat)
@@ -91,11 +92,11 @@ colformat_char <- function(x, ...){
 }
 
 #' @export
-#' @title format numeric columns
-#' @description Format numeric columns in a flextable.
+#' @title format numeric cells
+#' @description Format numeric cells in a flextable.
 #' @inheritParams colformat_char
 #' @param big.mark,digits see \code{\link[base]{formatC}}
-#' @family columns formatters
+#' @family cells formatters
 #' @examples
 #' dat <- iris
 #' dat[1:4, 1] <- NA
@@ -112,11 +113,11 @@ colformat_num <- function(x, ...){
   UseMethod("colformat_num")
 }
 
-#' @title format integer columns
-#' @description Format integer columns in a flextable.
+#' @title format integer cells
+#' @description Format integer cells in a flextable.
 #' @inheritParams colformat_char
 #' @param big.mark see \code{\link[base]{formatC}}
-#' @family columns formatters
+#' @family cells formatters
 #' @export
 #' @examples
 #' dat <- mtcars
@@ -129,11 +130,11 @@ colformat_int <- function(x, ...){
   UseMethod("colformat_int")
 }
 
-#' @title format logical columns
-#' @description Format logical columns in a flextable.
+#' @title format logical cells
+#' @description Format logical cells in a flextable.
 #' @inheritParams colformat_char
-#' @param false,true string to be used for logical columns
-#' @family columns formatters
+#' @param false,true string to be used for logical
+#' @family cells formatters
 #' @export
 #' @examples
 #' dat <- data.frame(a = c(TRUE, FALSE), b = c(FALSE, TRUE))
@@ -154,7 +155,7 @@ colformat_num.flextable <- function(x, col_keys, big.mark=",", digits = 2, na_st
     out <- paste0(prefix, formatC(x, format="f", big.mark=big.mark, digits = digits), suffix )
     ifelse(is.na(x), na_str, out)
   }
-  docall_display(col_keys, fun_, x)
+  docall_display(col_keys, fun_, x, ...)
 }
 
 
@@ -165,7 +166,7 @@ colformat_int.flextable <- function(x, col_keys, big.mark=",", na_str = "", pref
     out <- paste0(prefix, formatC(x, format="f", big.mark=big.mark, digits = 0), suffix )
     ifelse(is.na(x), na_str, out)
   }
-  docall_display(col_keys, fun_, x)
+  docall_display(col_keys, fun_, x, ...)
 }
 
 #' @export
@@ -177,7 +178,7 @@ colformat_lgl.flextable <- function(x, col_keys,
     out <- ifelse(x, true, false)
     ifelse(is.na(x), na_str, out)
   }
-  docall_display(col_keys, fun_, x)
+  docall_display(col_keys, fun_, x, ...)
 }
 
 
@@ -188,13 +189,13 @@ colformat_char.flextable <- function(x, col_keys, na_str = "", prefix = "", suff
     out <- paste0(prefix, x, suffix )
     ifelse(is.na(x), na_str, out)
   }
-  docall_display(col_keys, fun_, x)
+  docall_display(col_keys, fun_, x, ...)
 }
 
 
-docall_display <- function(col_keys, format_fun, x){
+docall_display <- function(col_keys, format_fun, x, i = NULL){
   for( varname in col_keys){
-    x <- compose(x = x, j = varname, value = as_paragraph(as_chunk(format_fun(get(varname)))), part = "body" )
+    x <- compose(x = x, j = varname, i = i, value = as_paragraph(as_chunk(format_fun(get(varname)))), part = "body" )
   }
   x
 }
